import { Expectation } from '@serenity-js/core';
/**
 * Produces an {@apilink Expectation|expectation} that negates the provided `expectation`.
 *
 * ## Ensuring that the actual value does not equal the expected value
 *
 * ```ts
 * import { actorCalled } from '@serenity-js/core'
 * import { Ensure, equals, not } from '@serenity-js/assertions'
 *
 * const actual   = { name: 'apples' }
 * const expected = { name: 'bananas' }
 *
 * await actorCalled('Ester').attemptsTo(
 *   Ensure.that(actual, not(equals(expected))),
 * )
 * ```
 *
 * @param expectation
 *
 * @group Expectations
 */
export declare function not<Actual>(expectation: Expectation<Actual>): Expectation<Actual>;
//# sourceMappingURL=not.d.ts.map